
package org.objectweb.fractal.bf.adl.exporter;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.logging.Logger;

import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.bf.BindingFactory;
import org.objectweb.fractal.bf.BindingFactoryException;
import org.objectweb.fractal.bf.BindingFactoryHelper;
import org.objectweb.fractal.bf.ExportMode;
import org.objectweb.fractal.bf.adl.common.Parameter;

/**
 * An exporter builder meant to be used with the dynamic backend of Fractal-BF
 * ADL.
 */
public class DynamicExporterBuilder implements ExporterBuilder
{

  Logger log = Logger
                 .getLogger(DynamicExporterBuilder.class.getCanonicalName());

  /**
   * @throws BindingFactoryException
   * @see org.objectweb.fractal.bf.adl.exporter.ExporterBuilder#export(java.lang.String,
   *      java.lang.Object, java.util.List, String, Object)
   */
  public void export(String itfName, Object c, List<Parameter> parameters,
      String type, Object context) throws BindingFactoryException
  {

    Map<String, String> exportHints = new HashMap<String, String>();
    /* fill the export hints map */
    for (Parameter p : parameters)
      exportHints.put(p.getName(), p.getValue());

    exportHints.put(ExportMode.EXPORT_MODE, type);

    log
        .config("BindingFactory will export with the following parameters: [itf,"
            + itfName + "],[params:" + exportHints.toString() + "]");

    BindingFactory bf = BindingFactoryHelper.getBindingFactory();
    Component component = (Component) c;
    bf.export(component, itfName, exportHints);
  }

}
